@@ -1,21 +1,48 @@
 var annotated_dup =
 [
     [ "uhd", "namespaceuhd.html", [
+      [ "usrp", "namespaceuhd_1_1usrp.html", [
+        [ "cal", "namespaceuhd_1_1usrp_1_1cal.html", [
+          [ "container", "classuhd_1_1usrp_1_1cal_1_1container.html", "classuhd_1_1usrp_1_1cal_1_1container" ],
+          [ "database", "classuhd_1_1usrp_1_1cal_1_1database.html", "classuhd_1_1usrp_1_1cal_1_1database" ],
+          [ "zbx_tx_dsa_cal", "classuhd_1_1usrp_1_1cal_1_1zbx__tx__dsa__cal.html", "classuhd_1_1usrp_1_1cal_1_1zbx__tx__dsa__cal" ],
+          [ "zbx_rx_dsa_cal", "classuhd_1_1usrp_1_1cal_1_1zbx__rx__dsa__cal.html", "classuhd_1_1usrp_1_1cal_1_1zbx__rx__dsa__cal" ],
+          [ "iq_cal", "classuhd_1_1usrp_1_1cal_1_1iq__cal.html", "classuhd_1_1usrp_1_1cal_1_1iq__cal" ],
+          [ "pwr_cal", "classuhd_1_1usrp_1_1cal_1_1pwr__cal.html", "classuhd_1_1usrp_1_1cal_1_1pwr__cal" ]
+        ] ],
+        [ "zbx", "namespaceuhd_1_1usrp_1_1zbx.html", [
+          [ "zbx_tune_map_item_t", "structuhd_1_1usrp_1_1zbx_1_1zbx__tune__map__item__t.html", "structuhd_1_1usrp_1_1zbx_1_1zbx__tune__map__item__t" ]
+        ] ],
+        [ "component_file_t", "structuhd_1_1usrp_1_1component__file__t.html", "structuhd_1_1usrp_1_1component__file__t" ],
+        [ "dboard_base", "classuhd_1_1usrp_1_1dboard__base.html", "classuhd_1_1usrp_1_1dboard__base" ],
+        [ "xcvr_dboard_base", "classuhd_1_1usrp_1_1xcvr__dboard__base.html", "classuhd_1_1usrp_1_1xcvr__dboard__base" ],
+        [ "rx_dboard_base", "classuhd_1_1usrp_1_1rx__dboard__base.html", "classuhd_1_1usrp_1_1rx__dboard__base" ],
+        [ "tx_dboard_base", "classuhd_1_1usrp_1_1tx__dboard__base.html", "classuhd_1_1usrp_1_1tx__dboard__base" ],
+        [ "dboard_eeprom_t", "structuhd_1_1usrp_1_1dboard__eeprom__t.html", "structuhd_1_1usrp_1_1dboard__eeprom__t" ],
+        [ "dboard_id_t", "classuhd_1_1usrp_1_1dboard__id__t.html", "classuhd_1_1usrp_1_1dboard__id__t" ],
+        [ "dboard_iface_special_props_t", "structuhd_1_1usrp_1_1dboard__iface__special__props__t.html", "structuhd_1_1usrp_1_1dboard__iface__special__props__t" ],
+        [ "dboard_iface", "classuhd_1_1usrp_1_1dboard__iface.html", "classuhd_1_1usrp_1_1dboard__iface" ],
+        [ "dboard_manager", "classuhd_1_1usrp_1_1dboard__manager.html", "classuhd_1_1usrp_1_1dboard__manager" ],
+        [ "fe_connection_t", "classuhd_1_1usrp_1_1fe__connection__t.html", "classuhd_1_1usrp_1_1fe__connection__t" ],
+        [ "multi_usrp", "classuhd_1_1usrp_1_1multi__usrp.html", "classuhd_1_1usrp_1_1multi__usrp" ],
+        [ "subdev_spec_pair_t", "structuhd_1_1usrp_1_1subdev__spec__pair__t.html", "structuhd_1_1usrp_1_1subdev__spec__pair__t" ],
+        [ "subdev_spec_t", "classuhd_1_1usrp_1_1subdev__spec__t.html", "classuhd_1_1usrp_1_1subdev__spec__t" ]
+      ] ],
       [ "convert", "namespaceuhd_1_1convert.html", [
         [ "converter", "classuhd_1_1convert_1_1converter.html", "classuhd_1_1convert_1_1converter" ],
         [ "id_type", "structuhd_1_1convert_1_1id__type.html", "structuhd_1_1convert_1_1id__type" ]
       ] ],
       [ "experts", "namespaceuhd_1_1experts.html", [
-        [ "dag_vertex_t", "classuhd_1_1experts_1_1dag__vertex__t.html", "classuhd_1_1experts_1_1dag__vertex__t" ],
-        [ "data_accessor_base", "classuhd_1_1experts_1_1data__accessor__base.html", "classuhd_1_1experts_1_1data__accessor__base" ],
-        [ "data_accessor_t", "classuhd_1_1experts_1_1data__accessor__t.html", "classuhd_1_1experts_1_1data__accessor__t" ],
-        [ "data_node_printer", "classuhd_1_1experts_1_1data__node__printer.html", null ],
-        [ "data_node_t", "classuhd_1_1experts_1_1data__node__t.html", "classuhd_1_1experts_1_1data__node__t" ],
-        [ "data_reader_t", "classuhd_1_1experts_1_1data__reader__t.html", "classuhd_1_1experts_1_1data__reader__t" ],
-        [ "data_writer_t", "classuhd_1_1experts_1_1data__writer__t.html", "classuhd_1_1experts_1_1data__writer__t" ],
         [ "expert_container", "classuhd_1_1experts_1_1expert__container.html", "classuhd_1_1experts_1_1expert__container" ],
         [ "expert_factory", "classuhd_1_1experts_1_1expert__factory.html", null ],
+        [ "dag_vertex_t", "classuhd_1_1experts_1_1dag__vertex__t.html", "classuhd_1_1experts_1_1dag__vertex__t" ],
+        [ "data_node_printer", "classuhd_1_1experts_1_1data__node__printer.html", null ],
+        [ "data_node_t", "classuhd_1_1experts_1_1data__node__t.html", "classuhd_1_1experts_1_1data__node__t" ],
         [ "node_retriever_t", "classuhd_1_1experts_1_1node__retriever__t.html", "classuhd_1_1experts_1_1node__retriever__t" ],
+        [ "data_accessor_t", "classuhd_1_1experts_1_1data__accessor__t.html", "classuhd_1_1experts_1_1data__accessor__t" ],
+        [ "data_accessor_base", "classuhd_1_1experts_1_1data__accessor__base.html", "classuhd_1_1experts_1_1data__accessor__base" ],
+        [ "data_reader_t", "classuhd_1_1experts_1_1data__reader__t.html", "classuhd_1_1experts_1_1data__reader__t" ],
+        [ "data_writer_t", "classuhd_1_1experts_1_1data__writer__t.html", "classuhd_1_1experts_1_1data__writer__t" ],
         [ "worker_node_t", "classuhd_1_1experts_1_1worker__node__t.html", "classuhd_1_1experts_1_1worker__node__t" ]
       ] ],
       [ "extension", "namespaceuhd_1_1extension.html", [
@@ -29,58 +56,51 @@ var annotated_dup =
         [ "gps_iface", "classuhd_1_1features_1_1gps__iface.html", "classuhd_1_1features_1_1gps__iface" ],
         [ "internal_sync_iface", "classuhd_1_1features_1_1internal__sync__iface.html", "classuhd_1_1features_1_1internal__sync__iface" ],
         [ "ref_clk_calibration_iface", "classuhd_1_1features_1_1ref__clk__calibration__iface.html", "classuhd_1_1features_1_1ref__clk__calibration__iface" ],
-        [ "spi_getter_iface", "classuhd_1_1features_1_1spi__getter__iface.html", "classuhd_1_1features_1_1spi__getter__iface" ],
         [ "spi_periph_config_t", "structuhd_1_1features_1_1spi__periph__config__t.html", "structuhd_1_1features_1_1spi__periph__config__t" ],
+        [ "spi_getter_iface", "classuhd_1_1features_1_1spi__getter__iface.html", "classuhd_1_1features_1_1spi__getter__iface" ],
         [ "trig_io_mode_iface", "classuhd_1_1features_1_1trig__io__mode__iface.html", "classuhd_1_1features_1_1trig__io__mode__iface" ]
       ] ],
-      [ "log", "namespaceuhd_1_1log.html", [
-        [ "logging_info", "structuhd_1_1log_1_1logging__info.html", "structuhd_1_1log_1_1logging__info" ]
-      ] ],
-      [ "math", "namespaceuhd_1_1math.html", [
-        [ "fp_compare", "namespaceuhd_1_1math_1_1fp__compare.html", [
-          [ "fp_compare_delta", "classuhd_1_1math_1_1fp__compare_1_1fp__compare__delta.html", "classuhd_1_1math_1_1fp__compare_1_1fp__compare__delta" ],
-          [ "fp_compare_epsilon", "classuhd_1_1math_1_1fp__compare_1_1fp__compare__epsilon.html", "classuhd_1_1math_1_1fp__compare_1_1fp__compare__epsilon" ],
-          [ "freq_compare_epsilon", "classuhd_1_1math_1_1fp__compare_1_1freq__compare__epsilon.html", "classuhd_1_1math_1_1fp__compare_1_1freq__compare__epsilon" ]
-        ] ]
-      ] ],
       [ "rfnoc", "namespaceuhd_1_1rfnoc.html", [
         [ "chdr", "namespaceuhd_1_1rfnoc_1_1chdr.html", [
           [ "chdr_header", "classuhd_1_1rfnoc_1_1chdr_1_1chdr__header.html", "classuhd_1_1rfnoc_1_1chdr_1_1chdr__header" ],
           [ "ctrl_payload", "classuhd_1_1rfnoc_1_1chdr_1_1ctrl__payload.html", "classuhd_1_1rfnoc_1_1chdr_1_1ctrl__payload" ],
-          [ "mgmt_hop_t", "classuhd_1_1rfnoc_1_1chdr_1_1mgmt__hop__t.html", "classuhd_1_1rfnoc_1_1chdr_1_1mgmt__hop__t" ],
-          [ "mgmt_op_t", "classuhd_1_1rfnoc_1_1chdr_1_1mgmt__op__t.html", "classuhd_1_1rfnoc_1_1chdr_1_1mgmt__op__t" ],
-          [ "mgmt_payload", "classuhd_1_1rfnoc_1_1chdr_1_1mgmt__payload.html", "classuhd_1_1rfnoc_1_1chdr_1_1mgmt__payload" ],
+          [ "strs_payload", "classuhd_1_1rfnoc_1_1chdr_1_1strs__payload.html", "classuhd_1_1rfnoc_1_1chdr_1_1strs__payload" ],
           [ "strc_payload", "classuhd_1_1rfnoc_1_1chdr_1_1strc__payload.html", "classuhd_1_1rfnoc_1_1chdr_1_1strc__payload" ],
-          [ "strs_payload", "classuhd_1_1rfnoc_1_1chdr_1_1strs__payload.html", "classuhd_1_1rfnoc_1_1chdr_1_1strs__payload" ]
+          [ "mgmt_op_t", "classuhd_1_1rfnoc_1_1chdr_1_1mgmt__op__t.html", "classuhd_1_1rfnoc_1_1chdr_1_1mgmt__op__t" ],
+          [ "mgmt_hop_t", "classuhd_1_1rfnoc_1_1chdr_1_1mgmt__hop__t.html", "classuhd_1_1rfnoc_1_1chdr_1_1mgmt__hop__t" ],
+          [ "mgmt_payload", "classuhd_1_1rfnoc_1_1chdr_1_1mgmt__payload.html", "classuhd_1_1rfnoc_1_1chdr_1_1mgmt__payload" ]
         ] ],
         [ "detail", "namespaceuhd_1_1rfnoc_1_1detail.html", [
-          [ "filter_node", "classuhd_1_1rfnoc_1_1detail_1_1filter__node.html", "classuhd_1_1rfnoc_1_1detail_1_1filter__node" ],
-          [ "graph_t", "classuhd_1_1rfnoc_1_1detail_1_1graph__t.html", "classuhd_1_1rfnoc_1_1detail_1_1graph__t" ]
+          [ "graph_t", "classuhd_1_1rfnoc_1_1detail_1_1graph__t.html", "classuhd_1_1rfnoc_1_1detail_1_1graph__t" ],
+          [ "filter_node", "classuhd_1_1rfnoc_1_1detail_1_1filter__node.html", "classuhd_1_1rfnoc_1_1detail_1_1filter__node" ]
+        ] ],
+        [ "test", "namespaceuhd_1_1rfnoc_1_1test.html", [
+          [ "mock_radio_node_t", "classuhd_1_1rfnoc_1_1test_1_1mock__radio__node__t.html", "classuhd_1_1rfnoc_1_1test_1_1mock__radio__node__t" ],
+          [ "mock_ddc_node_t", "classuhd_1_1rfnoc_1_1test_1_1mock__ddc__node__t.html", "classuhd_1_1rfnoc_1_1test_1_1mock__ddc__node__t" ],
+          [ "mock_fifo_t", "classuhd_1_1rfnoc_1_1test_1_1mock__fifo__t.html", "classuhd_1_1rfnoc_1_1test_1_1mock__fifo__t" ],
+          [ "mock_streamer_t", "classuhd_1_1rfnoc_1_1test_1_1mock__streamer__t.html", "classuhd_1_1rfnoc_1_1test_1_1mock__streamer__t" ],
+          [ "mock_terminator_t", "classuhd_1_1rfnoc_1_1test_1_1mock__terminator__t.html", "classuhd_1_1rfnoc_1_1test_1_1mock__terminator__t" ],
+          [ "mock_edge_node_t", "classuhd_1_1rfnoc_1_1test_1_1mock__edge__node__t.html", "classuhd_1_1rfnoc_1_1test_1_1mock__edge__node__t" ],
+          [ "mock_routing_node_t", "classuhd_1_1rfnoc_1_1test_1_1mock__routing__node__t.html", "classuhd_1_1rfnoc_1_1test_1_1mock__routing__node__t" ]
         ] ],
         [ "rf_control", "namespaceuhd_1_1rfnoc_1_1rf__control.html", [
           [ "antenna_iface", "classuhd_1_1rfnoc_1_1rf__control_1_1antenna__iface.html", "classuhd_1_1rfnoc_1_1rf__control_1_1antenna__iface" ],
+          [ "enumerated_antenna", "classuhd_1_1rfnoc_1_1rf__control_1_1enumerated__antenna.html", "classuhd_1_1rfnoc_1_1rf__control_1_1enumerated__antenna" ],
           [ "antenna_radio_control_mixin", "classuhd_1_1rfnoc_1_1rf__control_1_1antenna__radio__control__mixin.html", "classuhd_1_1rfnoc_1_1rf__control_1_1antenna__radio__control__mixin" ],
           [ "core_iface", "classuhd_1_1rfnoc_1_1rf__control_1_1core__iface.html", "classuhd_1_1rfnoc_1_1rf__control_1_1core__iface" ],
-          [ "enumerated_antenna", "classuhd_1_1rfnoc_1_1rf__control_1_1enumerated__antenna.html", "classuhd_1_1rfnoc_1_1rf__control_1_1enumerated__antenna" ],
           [ "nameless_gain_mixin", "classuhd_1_1rfnoc_1_1rf__control_1_1nameless__gain__mixin.html", "classuhd_1_1rfnoc_1_1rf__control_1_1nameless__gain__mixin" ],
           [ "power_reference_iface", "classuhd_1_1rfnoc_1_1rf__control_1_1power__reference__iface.html", "classuhd_1_1rfnoc_1_1rf__control_1_1power__reference__iface" ]
         ] ],
-        [ "test", "namespaceuhd_1_1rfnoc_1_1test.html", [
-          [ "mock_ddc_node_t", "classuhd_1_1rfnoc_1_1test_1_1mock__ddc__node__t.html", "classuhd_1_1rfnoc_1_1test_1_1mock__ddc__node__t" ],
-          [ "mock_edge_node_t", "classuhd_1_1rfnoc_1_1test_1_1mock__edge__node__t.html", "classuhd_1_1rfnoc_1_1test_1_1mock__edge__node__t" ],
-          [ "mock_fifo_t", "classuhd_1_1rfnoc_1_1test_1_1mock__fifo__t.html", "classuhd_1_1rfnoc_1_1test_1_1mock__fifo__t" ],
-          [ "mock_radio_node_t", "classuhd_1_1rfnoc_1_1test_1_1mock__radio__node__t.html", "classuhd_1_1rfnoc_1_1test_1_1mock__radio__node__t" ],
-          [ "mock_routing_node_t", "classuhd_1_1rfnoc_1_1test_1_1mock__routing__node__t.html", "classuhd_1_1rfnoc_1_1test_1_1mock__routing__node__t" ],
-          [ "mock_streamer_t", "classuhd_1_1rfnoc_1_1test_1_1mock__streamer__t.html", "classuhd_1_1rfnoc_1_1test_1_1mock__streamer__t" ],
-          [ "mock_terminator_t", "classuhd_1_1rfnoc_1_1test_1_1mock__terminator__t.html", "classuhd_1_1rfnoc_1_1test_1_1mock__terminator__t" ]
-        ] ],
         [ "action_info", "structuhd_1_1rfnoc_1_1action__info.html", "structuhd_1_1rfnoc_1_1action__info" ],
+        [ "stream_cmd_action_info", "structuhd_1_1rfnoc_1_1stream__cmd__action__info.html", "structuhd_1_1rfnoc_1_1stream__cmd__action__info" ],
+        [ "rx_event_action_info", "structuhd_1_1rfnoc_1_1rx__event__action__info.html", "structuhd_1_1rfnoc_1_1rx__event__action__info" ],
+        [ "tx_event_action_info", "structuhd_1_1rfnoc_1_1tx__event__action__info.html", "structuhd_1_1rfnoc_1_1tx__event__action__info" ],
+        [ "tune_request_action_info", "structuhd_1_1rfnoc_1_1tune__request__action__info.html", "structuhd_1_1rfnoc_1_1tune__request__action__info" ],
         [ "addsub_block_control", "classuhd_1_1rfnoc_1_1addsub__block__control.html", null ],
         [ "block_control", "classuhd_1_1rfnoc_1_1block__control.html", null ],
         [ "block_controller_factory", "classuhd_1_1rfnoc_1_1block__controller__factory.html", null ],
         [ "block_id_t", "classuhd_1_1rfnoc_1_1block__id__t.html", "classuhd_1_1rfnoc_1_1block__id__t" ],
         [ "blockdef", "classuhd_1_1rfnoc_1_1blockdef.html", "classuhd_1_1rfnoc_1_1blockdef" ],
-        [ "custom_register_space", "structuhd_1_1rfnoc_1_1custom__register__space.html", "structuhd_1_1rfnoc_1_1custom__register__space" ],
         [ "ddc_block_control", "classuhd_1_1rfnoc_1_1ddc__block__control.html", "classuhd_1_1rfnoc_1_1ddc__block__control" ],
         [ "dirtifier_t", "classuhd_1_1rfnoc_1_1dirtifier__t.html", "classuhd_1_1rfnoc_1_1dirtifier__t" ],
         [ "dmafifo_block_control", "classuhd_1_1rfnoc_1_1dmafifo__block__control.html", null ],
@@ -93,33 +113,30 @@ var annotated_dup =
         [ "lc_block_control", "classuhd_1_1rfnoc_1_1lc__block__control.html", "classuhd_1_1rfnoc_1_1lc__block__control" ],
         [ "logpwr_block_control", "classuhd_1_1rfnoc_1_1logpwr__block__control.html", null ],
         [ "mb_controller", "classuhd_1_1rfnoc_1_1mb__controller.html", "classuhd_1_1rfnoc_1_1mb__controller" ],
-        [ "mock_block_container", "structuhd_1_1rfnoc_1_1mock__block__container.html", "structuhd_1_1rfnoc_1_1mock__block__container" ],
         [ "mock_reg_iface_t", "classuhd_1_1rfnoc_1_1mock__reg__iface__t.html", "classuhd_1_1rfnoc_1_1mock__reg__iface__t" ],
+        [ "mock_block_container", "structuhd_1_1rfnoc_1_1mock__block__container.html", "structuhd_1_1rfnoc_1_1mock__block__container" ],
         [ "moving_average_block_control", "classuhd_1_1rfnoc_1_1moving__average__block__control.html", "classuhd_1_1rfnoc_1_1moving__average__block__control" ],
         [ "multichan_register_iface", "classuhd_1_1rfnoc_1_1multichan__register__iface.html", "classuhd_1_1rfnoc_1_1multichan__register__iface" ],
         [ "noc_block_base", "classuhd_1_1rfnoc_1_1noc__block__base.html", "classuhd_1_1rfnoc_1_1noc__block__base" ],
-        [ "node_accessor_t", "classuhd_1_1rfnoc_1_1node__accessor__t.html", "classuhd_1_1rfnoc_1_1node__accessor__t" ],
         [ "node_t", "classuhd_1_1rfnoc_1_1node__t.html", "classuhd_1_1rfnoc_1_1node__t" ],
+        [ "node_accessor_t", "classuhd_1_1rfnoc_1_1node__accessor__t.html", "classuhd_1_1rfnoc_1_1node__accessor__t" ],
         [ "null_block_control", "classuhd_1_1rfnoc_1_1null__block__control.html", "classuhd_1_1rfnoc_1_1null__block__control" ],
         [ "property_base_t", "classuhd_1_1rfnoc_1_1property__base__t.html", "classuhd_1_1rfnoc_1_1property__base__t" ],
         [ "property_t", "classuhd_1_1rfnoc_1_1property__t.html", "classuhd_1_1rfnoc_1_1property__t" ],
         [ "radio_control", "classuhd_1_1rfnoc_1_1radio__control.html", "classuhd_1_1rfnoc_1_1radio__control" ],
+        [ "custom_register_space", "structuhd_1_1rfnoc_1_1custom__register__space.html", "structuhd_1_1rfnoc_1_1custom__register__space" ],
         [ "register_iface", "classuhd_1_1rfnoc_1_1register__iface.html", "classuhd_1_1rfnoc_1_1register__iface" ],
         [ "register_iface_holder", "classuhd_1_1rfnoc_1_1register__iface__holder.html", "classuhd_1_1rfnoc_1_1register__iface__holder" ],
         [ "registry", "classuhd_1_1rfnoc_1_1registry.html", "classuhd_1_1rfnoc_1_1registry" ],
         [ "replay_block_control", "classuhd_1_1rfnoc_1_1replay__block__control.html", "classuhd_1_1rfnoc_1_1replay__block__control" ],
         [ "res_source_info", "structuhd_1_1rfnoc_1_1res__source__info.html", "structuhd_1_1rfnoc_1_1res__source__info" ],
-        [ "rfnoc_graph", "classuhd_1_1rfnoc_1_1rfnoc__graph.html", "classuhd_1_1rfnoc_1_1rfnoc__graph" ],
-        [ "rx_event_action_info", "structuhd_1_1rfnoc_1_1rx__event__action__info.html", "structuhd_1_1rfnoc_1_1rx__event__action__info" ],
         [ "siggen_block_control", "classuhd_1_1rfnoc_1_1siggen__block__control.html", "classuhd_1_1rfnoc_1_1siggen__block__control" ],
         [ "split_stream_block_control", "classuhd_1_1rfnoc_1_1split__stream__block__control.html", null ],
-        [ "stream_cmd_action_info", "structuhd_1_1rfnoc_1_1stream__cmd__action__info.html", "structuhd_1_1rfnoc_1_1stream__cmd__action__info" ],
         [ "switchboard_block_control", "classuhd_1_1rfnoc_1_1switchboard__block__control.html", "classuhd_1_1rfnoc_1_1switchboard__block__control" ],
         [ "traffic_counter", "classuhd_1_1rfnoc_1_1traffic__counter.html", "classuhd_1_1rfnoc_1_1traffic__counter" ],
-        [ "tune_request_action_info", "structuhd_1_1rfnoc_1_1tune__request__action__info.html", "structuhd_1_1rfnoc_1_1tune__request__action__info" ],
-        [ "tx_event_action_info", "structuhd_1_1rfnoc_1_1tx__event__action__info.html", "structuhd_1_1rfnoc_1_1tx__event__action__info" ],
         [ "vector_iir_block_control", "classuhd_1_1rfnoc_1_1vector__iir__block__control.html", "classuhd_1_1rfnoc_1_1vector__iir__block__control" ],
-        [ "window_block_control", "classuhd_1_1rfnoc_1_1window__block__control.html", "classuhd_1_1rfnoc_1_1window__block__control" ]
+        [ "window_block_control", "classuhd_1_1rfnoc_1_1window__block__control.html", "classuhd_1_1rfnoc_1_1window__block__control" ],
+        [ "rfnoc_graph", "classuhd_1_1rfnoc_1_1rfnoc__graph.html", "classuhd_1_1rfnoc_1_1rfnoc__graph" ]
       ] ],
       [ "transport", "namespaceuhd_1_1transport.html", [
         [ "vrt", "namespaceuhd_1_1transport_1_1vrt.html", [
@@ -130,43 +147,16 @@ var annotated_dup =
         [ "buffer_pool", "classuhd_1_1transport_1_1buffer__pool.html", "classuhd_1_1transport_1_1buffer__pool" ],
         [ "frame_buff", "classuhd_1_1transport_1_1frame__buff.html", "classuhd_1_1transport_1_1frame__buff" ],
         [ "if_addrs_t", "structuhd_1_1transport_1_1if__addrs__t.html", "structuhd_1_1transport_1_1if__addrs__t" ],
-        [ "managed_buffer", "classuhd_1_1transport_1_1managed__buffer.html", "classuhd_1_1transport_1_1managed__buffer" ],
-        [ "managed_recv_buffer", "classuhd_1_1transport_1_1managed__recv__buffer.html", "classuhd_1_1transport_1_1managed__recv__buffer" ],
-        [ "managed_send_buffer", "classuhd_1_1transport_1_1managed__send__buffer.html", "classuhd_1_1transport_1_1managed__send__buffer" ],
         [ "udp_simple", "classuhd_1_1transport_1_1udp__simple.html", "classuhd_1_1transport_1_1udp__simple" ],
         [ "udp_zero_copy", "classuhd_1_1transport_1_1udp__zero__copy.html", "classuhd_1_1transport_1_1udp__zero__copy" ],
         [ "usb_control", "classuhd_1_1transport_1_1usb__control.html", "classuhd_1_1transport_1_1usb__control" ],
         [ "usb_device_handle", "classuhd_1_1transport_1_1usb__device__handle.html", "classuhd_1_1transport_1_1usb__device__handle" ],
         [ "usb_zero_copy", "classuhd_1_1transport_1_1usb__zero__copy.html", "classuhd_1_1transport_1_1usb__zero__copy" ],
-        [ "zero_copy_if", "classuhd_1_1transport_1_1zero__copy__if.html", "classuhd_1_1transport_1_1zero__copy__if" ],
-        [ "zero_copy_xport_params", "structuhd_1_1transport_1_1zero__copy__xport__params.html", "structuhd_1_1transport_1_1zero__copy__xport__params" ]
-      ] ],
-      [ "usrp", "namespaceuhd_1_1usrp.html", [
-        [ "cal", "namespaceuhd_1_1usrp_1_1cal.html", [
-          [ "container", "classuhd_1_1usrp_1_1cal_1_1container.html", "classuhd_1_1usrp_1_1cal_1_1container" ],
-          [ "database", "classuhd_1_1usrp_1_1cal_1_1database.html", "classuhd_1_1usrp_1_1cal_1_1database" ],
-          [ "iq_cal", "classuhd_1_1usrp_1_1cal_1_1iq__cal.html", "classuhd_1_1usrp_1_1cal_1_1iq__cal" ],
-          [ "pwr_cal", "classuhd_1_1usrp_1_1cal_1_1pwr__cal.html", "classuhd_1_1usrp_1_1cal_1_1pwr__cal" ],
-          [ "zbx_rx_dsa_cal", "classuhd_1_1usrp_1_1cal_1_1zbx__rx__dsa__cal.html", "classuhd_1_1usrp_1_1cal_1_1zbx__rx__dsa__cal" ],
-          [ "zbx_tx_dsa_cal", "classuhd_1_1usrp_1_1cal_1_1zbx__tx__dsa__cal.html", "classuhd_1_1usrp_1_1cal_1_1zbx__tx__dsa__cal" ]
-        ] ],
-        [ "zbx", "namespaceuhd_1_1usrp_1_1zbx.html", [
-          [ "zbx_tune_map_item_t", "structuhd_1_1usrp_1_1zbx_1_1zbx__tune__map__item__t.html", "structuhd_1_1usrp_1_1zbx_1_1zbx__tune__map__item__t" ]
-        ] ],
-        [ "component_file_t", "structuhd_1_1usrp_1_1component__file__t.html", "structuhd_1_1usrp_1_1component__file__t" ],
-        [ "dboard_base", "classuhd_1_1usrp_1_1dboard__base.html", "classuhd_1_1usrp_1_1dboard__base" ],
-        [ "dboard_eeprom_t", "structuhd_1_1usrp_1_1dboard__eeprom__t.html", "structuhd_1_1usrp_1_1dboard__eeprom__t" ],
-        [ "dboard_id_t", "classuhd_1_1usrp_1_1dboard__id__t.html", "classuhd_1_1usrp_1_1dboard__id__t" ],
-        [ "dboard_iface", "classuhd_1_1usrp_1_1dboard__iface.html", "classuhd_1_1usrp_1_1dboard__iface" ],
-        [ "dboard_iface_special_props_t", "structuhd_1_1usrp_1_1dboard__iface__special__props__t.html", "structuhd_1_1usrp_1_1dboard__iface__special__props__t" ],
-        [ "dboard_manager", "classuhd_1_1usrp_1_1dboard__manager.html", "classuhd_1_1usrp_1_1dboard__manager" ],
-        [ "fe_connection_t", "classuhd_1_1usrp_1_1fe__connection__t.html", "classuhd_1_1usrp_1_1fe__connection__t" ],
-        [ "multi_usrp", "classuhd_1_1usrp_1_1multi__usrp.html", "classuhd_1_1usrp_1_1multi__usrp" ],
-        [ "rx_dboard_base", "classuhd_1_1usrp_1_1rx__dboard__base.html", "classuhd_1_1usrp_1_1rx__dboard__base" ],
-        [ "subdev_spec_pair_t", "structuhd_1_1usrp_1_1subdev__spec__pair__t.html", "structuhd_1_1usrp_1_1subdev__spec__pair__t" ],
-        [ "subdev_spec_t", "classuhd_1_1usrp_1_1subdev__spec__t.html", "classuhd_1_1usrp_1_1subdev__spec__t" ],
-        [ "tx_dboard_base", "classuhd_1_1usrp_1_1tx__dboard__base.html", "classuhd_1_1usrp_1_1tx__dboard__base" ],
-        [ "xcvr_dboard_base", "classuhd_1_1usrp_1_1xcvr__dboard__base.html", "classuhd_1_1usrp_1_1xcvr__dboard__base" ]
+        [ "managed_buffer", "classuhd_1_1transport_1_1managed__buffer.html", "classuhd_1_1transport_1_1managed__buffer" ],
+        [ "managed_recv_buffer", "classuhd_1_1transport_1_1managed__recv__buffer.html", "classuhd_1_1transport_1_1managed__recv__buffer" ],
+        [ "managed_send_buffer", "classuhd_1_1transport_1_1managed__send__buffer.html", "classuhd_1_1transport_1_1managed__send__buffer" ],
+        [ "zero_copy_xport_params", "structuhd_1_1transport_1_1zero__copy__xport__params.html", "structuhd_1_1transport_1_1zero__copy__xport__params" ],
+        [ "zero_copy_if", "classuhd_1_1transport_1_1zero__copy__if.html", "classuhd_1_1transport_1_1zero__copy__if" ]
       ] ],
       [ "usrp_clock", "namespaceuhd_1_1usrp__clock.html", [
         [ "multi_usrp_clock", "classuhd_1_1usrp__clock_1_1multi__usrp__clock.html", "classuhd_1_1usrp__clock_1_1multi__usrp__clock" ],
@@ -178,80 +168,90 @@ var annotated_dup =
         ] ],
         [ "scope_exit", "classuhd_1_1utils_1_1scope__exit.html", "classuhd_1_1utils_1_1scope__exit" ]
       ] ],
-      [ "access_error", "structuhd_1_1access__error.html", "structuhd_1_1access__error" ],
-      [ "analog_filter_base", "classuhd_1_1analog__filter__base.html", "classuhd_1_1analog__filter__base" ],
-      [ "analog_filter_lp", "classuhd_1_1analog__filter__lp.html", "classuhd_1_1analog__filter__lp" ],
-      [ "assertion_error", "structuhd_1_1assertion__error.html", "structuhd_1_1assertion__error" ],
-      [ "async_metadata_t", "structuhd_1_1async__metadata__t.html", "structuhd_1_1async__metadata__t" ],
-      [ "compat_num", "classuhd_1_1compat__num.html", "classuhd_1_1compat__num" ],
-      [ "compat_num16", "classuhd_1_1compat__num16.html", "classuhd_1_1compat__num16" ],
-      [ "compat_num32", "classuhd_1_1compat__num32.html", "classuhd_1_1compat__num32" ],
+      [ "math", "namespaceuhd_1_1math.html", [
+        [ "fp_compare", "namespaceuhd_1_1math_1_1fp__compare.html", [
+          [ "fp_compare_epsilon", "classuhd_1_1math_1_1fp__compare_1_1fp__compare__epsilon.html", "classuhd_1_1math_1_1fp__compare_1_1fp__compare__epsilon" ],
+          [ "freq_compare_epsilon", "classuhd_1_1math_1_1fp__compare_1_1freq__compare__epsilon.html", "classuhd_1_1math_1_1fp__compare_1_1freq__compare__epsilon" ],
+          [ "fp_compare_delta", "classuhd_1_1math_1_1fp__compare_1_1fp__compare__delta.html", "classuhd_1_1math_1_1fp__compare_1_1fp__compare__delta" ]
+        ] ]
+      ] ],
+      [ "log", "namespaceuhd_1_1log.html", [
+        [ "logging_info", "structuhd_1_1log_1_1logging__info.html", "structuhd_1_1log_1_1logging__info" ]
+      ] ],
       [ "device", "classuhd_1_1device.html", "classuhd_1_1device" ],
+      [ "exception", "structuhd_1_1exception.html", "structuhd_1_1exception" ],
+      [ "assertion_error", "structuhd_1_1assertion__error.html", "structuhd_1_1assertion__error" ],
+      [ "lookup_error", "structuhd_1_1lookup__error.html", "structuhd_1_1lookup__error" ],
+      [ "index_error", "structuhd_1_1index__error.html", "structuhd_1_1index__error" ],
+      [ "key_error", "structuhd_1_1key__error.html", "structuhd_1_1key__error" ],
+      [ "type_error", "structuhd_1_1type__error.html", "structuhd_1_1type__error" ],
+      [ "value_error", "structuhd_1_1value__error.html", "structuhd_1_1value__error" ],
+      [ "narrowing_error", "structuhd_1_1narrowing__error.html", "structuhd_1_1narrowing__error" ],
+      [ "runtime_error", "structuhd_1_1runtime__error.html", "structuhd_1_1runtime__error" ],
+      [ "usb_error", "structuhd_1_1usb__error.html", "structuhd_1_1usb__error" ],
+      [ "not_implemented_error", "structuhd_1_1not__implemented__error.html", "structuhd_1_1not__implemented__error" ],
+      [ "access_error", "structuhd_1_1access__error.html", "structuhd_1_1access__error" ],
+      [ "environment_error", "structuhd_1_1environment__error.html", "structuhd_1_1environment__error" ],
+      [ "io_error", "structuhd_1_1io__error.html", "structuhd_1_1io__error" ],
+      [ "os_error", "structuhd_1_1os__error.html", "structuhd_1_1os__error" ],
+      [ "system_error", "structuhd_1_1system__error.html", "structuhd_1_1system__error" ],
+      [ "syntax_error", "structuhd_1_1syntax__error.html", "structuhd_1_1syntax__error" ],
+      [ "rfnoc_error", "structuhd_1_1rfnoc__error.html", "structuhd_1_1rfnoc__error" ],
+      [ "op_failed", "structuhd_1_1op__failed.html", "structuhd_1_1op__failed" ],
+      [ "op_timeout", "structuhd_1_1op__timeout.html", "structuhd_1_1op__timeout" ],
+      [ "op_seqerr", "structuhd_1_1op__seqerr.html", "structuhd_1_1op__seqerr" ],
+      [ "op_timerr", "structuhd_1_1op__timerr.html", "structuhd_1_1op__timerr" ],
+      [ "resolve_error", "structuhd_1_1resolve__error.html", "structuhd_1_1resolve__error" ],
+      [ "routing_error", "structuhd_1_1routing__error.html", "structuhd_1_1routing__error" ],
+      [ "image_loader", "classuhd_1_1image__loader.html", "classuhd_1_1image__loader" ],
+      [ "property_iface", "classuhd_1_1property__iface.html", "classuhd_1_1property__iface" ],
+      [ "property", "classuhd_1_1property.html", "classuhd_1_1property" ],
+      [ "fs_path", "structuhd_1_1fs__path.html", "structuhd_1_1fs__path" ],
+      [ "property_tree", "classuhd_1_1property__tree.html", "classuhd_1_1property__tree" ],
+      [ "stream_args_t", "structuhd_1_1stream__args__t.html", "structuhd_1_1stream__args__t" ],
+      [ "rx_streamer", "classuhd_1_1rx__streamer.html", "classuhd_1_1rx__streamer" ],
+      [ "tx_streamer", "classuhd_1_1tx__streamer.html", "classuhd_1_1tx__streamer" ],
       [ "device_addr_t", "classuhd_1_1device__addr__t.html", "classuhd_1_1device__addr__t" ],
       [ "dict", "classuhd_1_1dict.html", "classuhd_1_1dict" ],
+      [ "filter_info_base", "classuhd_1_1filter__info__base.html", "classuhd_1_1filter__info__base" ],
+      [ "analog_filter_base", "classuhd_1_1analog__filter__base.html", "classuhd_1_1analog__filter__base" ],
+      [ "analog_filter_lp", "classuhd_1_1analog__filter__lp.html", "classuhd_1_1analog__filter__lp" ],
       [ "digital_filter_base", "classuhd_1_1digital__filter__base.html", "classuhd_1_1digital__filter__base" ],
       [ "digital_filter_fir", "classuhd_1_1digital__filter__fir.html", "classuhd_1_1digital__filter__fir" ],
-      [ "dirty_tracked", "classuhd_1_1dirty__tracked.html", "classuhd_1_1dirty__tracked" ],
-      [ "environment_error", "structuhd_1_1environment__error.html", "structuhd_1_1environment__error" ],
-      [ "exception", "structuhd_1_1exception.html", "structuhd_1_1exception" ],
-      [ "filter_info_base", "classuhd_1_1filter__info__base.html", "classuhd_1_1filter__info__base" ],
-      [ "fs_path", "structuhd_1_1fs__path.html", "structuhd_1_1fs__path" ],
-      [ "gain_fcns_t", "structuhd_1_1gain__fcns__t.html", "structuhd_1_1gain__fcns__t" ],
-      [ "gain_group", "classuhd_1_1gain__group.html", "classuhd_1_1gain__group" ],
-      [ "i2c_iface", "classuhd_1_1i2c__iface.html", "classuhd_1_1i2c__iface" ],
-      [ "image_loader", "classuhd_1_1image__loader.html", "classuhd_1_1image__loader" ],
-      [ "index_error", "structuhd_1_1index__error.html", "structuhd_1_1index__error" ],
-      [ "io_error", "structuhd_1_1io__error.html", "structuhd_1_1io__error" ],
-      [ "key_error", "structuhd_1_1key__error.html", "structuhd_1_1key__error" ],
-      [ "lookup_error", "structuhd_1_1lookup__error.html", "structuhd_1_1lookup__error" ],
       [ "mac_addr_t", "classuhd_1_1mac__addr__t.html", "classuhd_1_1mac__addr__t" ],
       [ "memmap32_iface", "structuhd_1_1memmap32__iface.html", "structuhd_1_1memmap32__iface" ],
       [ "memmap32_iface_timed", "structuhd_1_1memmap32__iface__timed.html", "structuhd_1_1memmap32__iface__timed" ],
-      [ "meta_range_t", "structuhd_1_1meta__range__t.html", "structuhd_1_1meta__range__t" ],
-      [ "msg_task", "classuhd_1_1msg__task.html", "classuhd_1_1msg__task" ],
-      [ "narrowing_error", "structuhd_1_1narrowing__error.html", "structuhd_1_1narrowing__error" ],
-      [ "not_implemented_error", "structuhd_1_1not__implemented__error.html", "structuhd_1_1not__implemented__error" ],
-      [ "op_failed", "structuhd_1_1op__failed.html", "structuhd_1_1op__failed" ],
-      [ "op_seqerr", "structuhd_1_1op__seqerr.html", "structuhd_1_1op__seqerr" ],
-      [ "op_timeout", "structuhd_1_1op__timeout.html", "structuhd_1_1op__timeout" ],
-      [ "op_timerr", "structuhd_1_1op__timerr.html", "structuhd_1_1op__timerr" ],
-      [ "os_error", "structuhd_1_1os__error.html", "structuhd_1_1os__error" ],
-      [ "property", "classuhd_1_1property.html", "classuhd_1_1property" ],
-      [ "property_iface", "classuhd_1_1property__iface.html", "classuhd_1_1property__iface" ],
-      [ "property_tree", "classuhd_1_1property__tree.html", "classuhd_1_1property__tree" ],
-      [ "range_t", "classuhd_1_1range__t.html", "classuhd_1_1range__t" ],
-      [ "ref_vector", "classuhd_1_1ref__vector.html", "classuhd_1_1ref__vector" ],
-      [ "resolve_error", "structuhd_1_1resolve__error.html", "structuhd_1_1resolve__error" ],
-      [ "rfnoc_error", "structuhd_1_1rfnoc__error.html", "structuhd_1_1rfnoc__error" ],
-      [ "routing_error", "structuhd_1_1routing__error.html", "structuhd_1_1routing__error" ],
-      [ "runtime_error", "structuhd_1_1runtime__error.html", "structuhd_1_1runtime__error" ],
       [ "rx_metadata_t", "structuhd_1_1rx__metadata__t.html", "structuhd_1_1rx__metadata__t" ],
-      [ "rx_streamer", "classuhd_1_1rx__streamer.html", "classuhd_1_1rx__streamer" ],
+      [ "tx_metadata_t", "structuhd_1_1tx__metadata__t.html", "structuhd_1_1tx__metadata__t" ],
+      [ "async_metadata_t", "structuhd_1_1async__metadata__t.html", "structuhd_1_1async__metadata__t" ],
+      [ "range_t", "classuhd_1_1range__t.html", "classuhd_1_1range__t" ],
+      [ "meta_range_t", "structuhd_1_1meta__range__t.html", "structuhd_1_1meta__range__t" ],
+      [ "ref_vector", "classuhd_1_1ref__vector.html", "classuhd_1_1ref__vector" ],
       [ "sensor_value_t", "structuhd_1_1sensor__value__t.html", "structuhd_1_1sensor__value__t" ],
-      [ "soft_register_base", "classuhd_1_1soft__register__base.html", "classuhd_1_1soft__register__base" ],
-      [ "soft_register_sync_t", "classuhd_1_1soft__register__sync__t.html", "classuhd_1_1soft__register__sync__t" ],
-      [ "soft_register_t", "classuhd_1_1soft__register__t.html", "classuhd_1_1soft__register__t" ],
-      [ "soft_regmap_accessor_t", "classuhd_1_1soft__regmap__accessor__t.html", "classuhd_1_1soft__regmap__accessor__t" ],
-      [ "soft_regmap_db_t", "classuhd_1_1soft__regmap__db__t.html", "classuhd_1_1soft__regmap__db__t" ],
-      [ "soft_regmap_t", "classuhd_1_1soft__regmap__t.html", "classuhd_1_1soft__regmap__t" ],
+      [ "i2c_iface", "classuhd_1_1i2c__iface.html", "classuhd_1_1i2c__iface" ],
       [ "spi_config_t", "structuhd_1_1spi__config__t.html", "structuhd_1_1spi__config__t" ],
       [ "spi_iface", "classuhd_1_1spi__iface.html", "classuhd_1_1spi__iface" ],
-      [ "stream_args_t", "structuhd_1_1stream__args__t.html", "structuhd_1_1stream__args__t" ],
+      [ "uart_iface", "classuhd_1_1uart__iface.html", "classuhd_1_1uart__iface" ],
       [ "stream_cmd_t", "structuhd_1_1stream__cmd__t.html", "structuhd_1_1stream__cmd__t" ],
-      [ "syntax_error", "structuhd_1_1syntax__error.html", "structuhd_1_1syntax__error" ],
-      [ "system_error", "structuhd_1_1system__error.html", "structuhd_1_1system__error" ],
-      [ "task", "classuhd_1_1task.html", "classuhd_1_1task" ],
       [ "time_spec_t", "classuhd_1_1time__spec__t.html", "classuhd_1_1time__spec__t" ],
-      [ "timed_wb_iface", "classuhd_1_1timed__wb__iface.html", "classuhd_1_1timed__wb__iface" ],
       [ "tune_request_t", "structuhd_1_1tune__request__t.html", "structuhd_1_1tune__request__t" ],
       [ "tune_result_t", "structuhd_1_1tune__result__t.html", "structuhd_1_1tune__result__t" ],
-      [ "tx_metadata_t", "structuhd_1_1tx__metadata__t.html", "structuhd_1_1tx__metadata__t" ],
-      [ "tx_streamer", "classuhd_1_1tx__streamer.html", "classuhd_1_1tx__streamer" ],
-      [ "type_error", "structuhd_1_1type__error.html", "structuhd_1_1type__error" ],
-      [ "uart_iface", "classuhd_1_1uart__iface.html", "classuhd_1_1uart__iface" ],
-      [ "usb_error", "structuhd_1_1usb__error.html", "structuhd_1_1usb__error" ],
-      [ "value_error", "structuhd_1_1value__error.html", "structuhd_1_1value__error" ],
-      [ "wb_iface", "classuhd_1_1wb__iface.html", "classuhd_1_1wb__iface" ]
+      [ "wb_iface", "classuhd_1_1wb__iface.html", "classuhd_1_1wb__iface" ],
+      [ "timed_wb_iface", "classuhd_1_1timed__wb__iface.html", "classuhd_1_1timed__wb__iface" ],
+      [ "compat_num", "classuhd_1_1compat__num.html", "classuhd_1_1compat__num" ],
+      [ "compat_num16", "classuhd_1_1compat__num16.html", "classuhd_1_1compat__num16" ],
+      [ "compat_num32", "classuhd_1_1compat__num32.html", "classuhd_1_1compat__num32" ],
+      [ "dirty_tracked", "classuhd_1_1dirty__tracked.html", "classuhd_1_1dirty__tracked" ],
+      [ "gain_fcns_t", "structuhd_1_1gain__fcns__t.html", "structuhd_1_1gain__fcns__t" ],
+      [ "gain_group", "classuhd_1_1gain__group.html", "classuhd_1_1gain__group" ],
+      [ "msg_task", "classuhd_1_1msg__task.html", "classuhd_1_1msg__task" ],
+      [ "soft_register_base", "classuhd_1_1soft__register__base.html", "classuhd_1_1soft__register__base" ],
+      [ "soft_register_t", "classuhd_1_1soft__register__t.html", "classuhd_1_1soft__register__t" ],
+      [ "soft_register_sync_t", "classuhd_1_1soft__register__sync__t.html", "classuhd_1_1soft__register__sync__t" ],
+      [ "soft_regmap_accessor_t", "classuhd_1_1soft__regmap__accessor__t.html", "classuhd_1_1soft__regmap__accessor__t" ],
+      [ "soft_regmap_t", "classuhd_1_1soft__regmap__t.html", "classuhd_1_1soft__regmap__t" ],
+      [ "soft_regmap_db_t", "classuhd_1_1soft__regmap__db__t.html", "classuhd_1_1soft__regmap__db__t" ],
+      [ "task", "classuhd_1_1task.html", "classuhd_1_1task" ]
     ] ],
     [ "_uhd_static_fixture", "struct__uhd__static__fixture.html", "struct__uhd__static__fixture" ],
     [ "uhd_range_t", "structuhd__range__t.html", "structuhd__range__t" ],
