@@ -3,7 +3,7 @@ var filters_8hpp =
     [ "uhd::filter_info_base", "classuhd_1_1filter__info__base.html", "classuhd_1_1filter__info__base" ],
     [ "uhd::analog_filter_base", "classuhd_1_1analog__filter__base.html", "classuhd_1_1analog__filter__base" ],
     [ "uhd::analog_filter_lp", "classuhd_1_1analog__filter__lp.html", "classuhd_1_1analog__filter__lp" ],
-    [ "uhd::digital_filter_base< tap_t >", "classuhd_1_1digital__filter__base.html", "classuhd_1_1digital__filter__base" ],
-    [ "uhd::digital_filter_fir< tap_t >", "classuhd_1_1digital__filter__fir.html", "classuhd_1_1digital__filter__fir" ],
+    [ "uhd::digital_filter_base&lt; tap_t &gt;", "classuhd_1_1digital__filter__base.html", "classuhd_1_1digital__filter__base" ],
+    [ "uhd::digital_filter_fir&lt; tap_t &gt;", "classuhd_1_1digital__filter__fir.html", "classuhd_1_1digital__filter__fir" ],
     [ "uhd::operator<<", "namespaceuhd.html#a9202606975ce2a6a6fb05af7efa97ef7", null ]
 ];
\ No newline at end of file
