@@ -15,23 +15,23 @@ var hierarchy =
       [ "uhd::rfnoc::rf_control::enumerated_antenna", "classuhd_1_1rfnoc_1_1rf__control_1_1enumerated__antenna.html", null ]
     ] ],
     [ "uhd::async_metadata_t", "structuhd_1_1async__metadata__t.html", null ],
-    [ "std::basic_string< Char >", null, [
+    [ "std::basic_string&lt; Char &gt;", null, [
       [ "std::string", null, [
         [ "uhd::fs_path", "structuhd_1_1fs__path.html", null ]
       ] ]
     ] ],
-    [ "uhd::rfnoc::block_controller_factory< T >", "classuhd_1_1rfnoc_1_1block__controller__factory.html", null ],
+    [ "uhd::rfnoc::block_controller_factory&lt; T &gt;", "classuhd_1_1rfnoc_1_1block__controller__factory.html", null ],
     [ "uhd::rfnoc::block_id_t", "classuhd_1_1rfnoc_1_1block__id__t.html", null ],
-    [ "uhd::transport::bounded_buffer< elem_type >", "classuhd_1_1transport_1_1bounded__buffer.html", null ],
+    [ "uhd::transport::bounded_buffer&lt; elem_type &gt;", "classuhd_1_1transport_1_1bounded__buffer.html", null ],
     [ "uhd::transport::udp_zero_copy::buff_params", "structuhd_1_1transport_1_1udp__zero__copy_1_1buff__params.html", null ],
     [ "uhd::rfnoc::chdr::mgmt_op_t::cfg_payload", "structuhd_1_1rfnoc_1_1chdr_1_1mgmt__op__t_1_1cfg__payload.html", null ],
     [ "uhd::rfnoc::chdr::chdr_header", "classuhd_1_1rfnoc_1_1chdr_1_1chdr__header.html", null ],
     [ "uhd::utils::chdr::chdr_packet", "classuhd_1_1utils_1_1chdr_1_1chdr__packet.html", null ],
-    [ "uhd::compat_num< major_type, minor_type >", "classuhd_1_1compat__num.html", null ],
-    [ "uhd::compat_num< uint16_t, uint16_t >", "classuhd_1_1compat__num.html", [
+    [ "uhd::compat_num&lt; major_type, minor_type &gt;", "classuhd_1_1compat__num.html", null ],
+    [ "uhd::compat_num&lt; uint16_t, uint16_t &gt;", "classuhd_1_1compat__num.html", [
       [ "uhd::compat_num32", "classuhd_1_1compat__num32.html", null ]
     ] ],
-    [ "uhd::compat_num< uint8_t, uint8_t >", "classuhd_1_1compat__num.html", [
+    [ "uhd::compat_num&lt; uint8_t, uint8_t &gt;", "classuhd_1_1compat__num.html", [
       [ "uhd::compat_num16", "classuhd_1_1compat__num16.html", null ]
     ] ],
     [ "uhd::usrp::component_file_t", "structuhd_1_1usrp_1_1component__file__t.html", null ],
@@ -61,14 +61,14 @@ var hierarchy =
     [ "uhd::usrp::dboard_eeprom_t", "structuhd_1_1usrp_1_1dboard__eeprom__t.html", null ],
     [ "uhd::usrp::dboard_iface_special_props_t", "structuhd_1_1usrp_1_1dboard__iface__special__props__t.html", null ],
     [ "uhd::transport::frame_buff::deleter", "structuhd_1_1transport_1_1frame__buff_1_1deleter.html", null ],
-    [ "uhd::dict< Key, Val >", "classuhd_1_1dict.html", null ],
-    [ "uhd::dict< std::string, std::string >", "classuhd_1_1dict.html", [
+    [ "uhd::dict&lt; Key, Val &gt;", "classuhd_1_1dict.html", null ],
+    [ "uhd::dict&lt; std::string, std::string &gt;", "classuhd_1_1dict.html", [
       [ "uhd::device_addr_t", "classuhd_1_1device__addr__t.html", null ],
       [ "uhd::rfnoc::blockdef::arg_t", "classuhd_1_1rfnoc_1_1blockdef_1_1arg__t.html", null ],
       [ "uhd::rfnoc::blockdef::port_t", "classuhd_1_1rfnoc_1_1blockdef_1_1port__t.html", null ],
       [ "uhd::usrp_clock::octoclock_eeprom_t", "classuhd_1_1usrp__clock_1_1octoclock__eeprom__t.html", null ]
     ] ],
-    [ "uhd::dirty_tracked< data_t >", "classuhd_1_1dirty__tracked.html", null ],
+    [ "uhd::dirty_tracked&lt; data_t &gt;", "classuhd_1_1dirty__tracked.html", null ],
     [ "uhd::features::discoverable_feature", "classuhd_1_1features_1_1discoverable__feature.html", [
       [ "uhd::features::adc_self_calibration_iface", "classuhd_1_1features_1_1adc__self__calibration__iface.html", null ],
       [ "uhd::features::gpio_power_iface", "classuhd_1_1features_1_1gpio__power__iface.html", null ],
@@ -136,9 +136,9 @@ var hierarchy =
       ] ]
     ] ],
     [ "uhd::rfnoc::detail::filter_node", "classuhd_1_1rfnoc_1_1detail_1_1filter__node.html", null ],
-    [ "uhd::math::fp_compare::fp_compare_delta< float_t >", "classuhd_1_1math_1_1fp__compare_1_1fp__compare__delta.html", null ],
-    [ "uhd::math::fp_compare::fp_compare_epsilon< float_t >", "classuhd_1_1math_1_1fp__compare_1_1fp__compare__epsilon.html", null ],
-    [ "uhd::math::fp_compare::fp_compare_epsilon< double >", "classuhd_1_1math_1_1fp__compare_1_1fp__compare__epsilon.html", [
+    [ "uhd::math::fp_compare::fp_compare_delta&lt; float_t &gt;", "classuhd_1_1math_1_1fp__compare_1_1fp__compare__delta.html", null ],
+    [ "uhd::math::fp_compare::fp_compare_epsilon&lt; float_t &gt;", "classuhd_1_1math_1_1fp__compare_1_1fp__compare__epsilon.html", null ],
+    [ "uhd::math::fp_compare::fp_compare_epsilon&lt; double &gt;", "classuhd_1_1math_1_1fp__compare_1_1fp__compare__epsilon.html", [
       [ "uhd::math::fp_compare::freq_compare_epsilon", "classuhd_1_1math_1_1fp__compare_1_1freq__compare__epsilon.html", null ]
     ] ],
     [ "uhd::transport::frame_buff", "classuhd_1_1transport_1_1frame__buff.html", null ],
@@ -271,7 +271,7 @@ var hierarchy =
       [ "uhd::property< T >", "classuhd_1_1property.html", null ]
     ] ],
     [ "uhd::range_t", "classuhd_1_1range__t.html", null ],
-    [ "uhd::ref_vector< T >", "classuhd_1_1ref__vector.html", null ],
+    [ "uhd::ref_vector&lt; T &gt;", "classuhd_1_1ref__vector.html", null ],
     [ "uhd::rfnoc::register_iface", "classuhd_1_1rfnoc_1_1register__iface.html", [
       [ "uhd::rfnoc::mock_reg_iface_t", "classuhd_1_1rfnoc_1_1mock__reg__iface__t.html", null ]
     ] ],
@@ -313,10 +313,10 @@ var hierarchy =
     [ "uhd_usrp_register_info_t", "structuhd__usrp__register__info__t.html", null ],
     [ "uhd_usrp_rx_info_t", "structuhd__usrp__rx__info__t.html", null ],
     [ "uhd_usrp_tx_info_t", "structuhd__usrp__tx__info__t.html", null ],
-    [ "std::vector< range_t >", null, [
+    [ "std::vector&lt; range_t &gt;", null, [
       [ "uhd::meta_range_t", "structuhd_1_1meta__range__t.html", null ]
     ] ],
-    [ "std::vector< subdev_spec_pair_t >", null, [
+    [ "std::vector&lt; subdev_spec_pair_t &gt;", null, [
       [ "uhd::usrp::subdev_spec_t", "classuhd_1_1usrp_1_1subdev__spec__t.html", null ]
     ] ],
     [ "uhd::wb_iface", "classuhd_1_1wb__iface.html", [
