@@ -1,6 +1,5 @@
 var NAVTREEINDEX18 =
 {
-"page_configuration.html#config_stream_args":[0,0,3,2],
 "page_configuration.html#config_stream_args_args":[0,0,3,2,2],
 "page_configuration.html#config_stream_args_channels":[0,0,3,2,3],
 "page_configuration.html#config_stream_args_cpu_format":[0,0,3,2,0],
@@ -18,31 +17,31 @@ var NAVTREEINDEX18 =
 "page_converters.html#converters_register":[0,1,4,3],
 "page_converters.html#converters_register_extra":[0,1,4,3,0],
 "page_converters.html#converters_register_internal":[0,1,4,3,1],
-"page_dboards.html":[0,0,25],
-"page_dboards.html#dboards":[0,0,25,0],
-"page_dboards.html#dboards_basicrx":[0,0,25,0,0],
-"page_dboards.html#dboards_basictx":[0,0,25,0,1],
-"page_dboards.html#dboards_cbx":[0,0,25,0,8],
-"page_dboards.html#dboards_clock_rate":[0,0,25,0,18],
-"page_dboards.html#dboards_dbsrx":[0,0,25,0,2],
-"page_dboards.html#dboards_dbsrx2":[0,0,25,0,3],
-"page_dboards.html#dboards_dbsrxmod":[0,0,25,0,19],
-"page_dboards.html#dboards_dbsrxmod_1":[0,0,25,0,19,0],
-"page_dboards.html#dboards_dbsrxmod_2":[0,0,25,0,19,1],
-"page_dboards.html#dboards_e300":[0,0,25,0,14],
-"page_dboards.html#dboards_fbx":[0,0,25,0,17],
-"page_dboards.html#dboards_n310":[0,0,25,0,15],
-"page_dboards.html#dboards_obx":[0,0,25,0,10],
-"page_dboards.html#dboards_rfx":[0,0,25,0,4],
-"page_dboards.html#dboards_rfxmod":[0,0,25,0,20],
-"page_dboards.html#dboards_sbx":[0,0,25,0,7],
-"page_dboards.html#dboards_tvrx":[0,0,25,0,12],
-"page_dboards.html#dboards_tvrx2":[0,0,25,0,13],
-"page_dboards.html#dboards_twinrx":[0,0,25,0,11],
-"page_dboards.html#dboards_ubx":[0,0,25,0,9],
-"page_dboards.html#dboards_wbx":[0,0,25,0,6],
-"page_dboards.html#dboards_xcvr":[0,0,25,0,5],
-"page_dboards.html#dboards_zbx":[0,0,25,0,16],
+"page_dboards.html":[0,0,23],
+"page_dboards.html#dboards":[0,0,23,0],
+"page_dboards.html#dboards_basicrx":[0,0,23,0,0],
+"page_dboards.html#dboards_basictx":[0,0,23,0,1],
+"page_dboards.html#dboards_cbx":[0,0,23,0,8],
+"page_dboards.html#dboards_clock_rate":[0,0,23,0,18],
+"page_dboards.html#dboards_dbsrx":[0,0,23,0,2],
+"page_dboards.html#dboards_dbsrx2":[0,0,23,0,3],
+"page_dboards.html#dboards_dbsrxmod":[0,0,23,0,19],
+"page_dboards.html#dboards_dbsrxmod_1":[0,0,23,0,19,0],
+"page_dboards.html#dboards_dbsrxmod_2":[0,0,23,0,19,1],
+"page_dboards.html#dboards_e300":[0,0,23,0,14],
+"page_dboards.html#dboards_fbx":[0,0,23,0,17],
+"page_dboards.html#dboards_n310":[0,0,23,0,15],
+"page_dboards.html#dboards_obx":[0,0,23,0,10],
+"page_dboards.html#dboards_rfx":[0,0,23,0,4],
+"page_dboards.html#dboards_rfxmod":[0,0,23,0,20],
+"page_dboards.html#dboards_sbx":[0,0,23,0,7],
+"page_dboards.html#dboards_tvrx":[0,0,23,0,12],
+"page_dboards.html#dboards_tvrx2":[0,0,23,0,13],
+"page_dboards.html#dboards_twinrx":[0,0,23,0,11],
+"page_dboards.html#dboards_ubx":[0,0,23,0,9],
+"page_dboards.html#dboards_wbx":[0,0,23,0,6],
+"page_dboards.html#dboards_xcvr":[0,0,23,0,5],
+"page_dboards.html#dboards_zbx":[0,0,23,0,16],
 "page_devices.html":[0,0],
 "page_devices.html#autotoc_md0":[0,0],
 "page_devices.html#autotoc_md1":[0,1],
@@ -67,22 +66,14 @@ var NAVTREEINDEX18 =
 "page_extension.html#extension_capabilities":[0,0,15,1],
 "page_extension.html#extension_howto":[0,0,15,1,0],
 "page_extension.html#extension_intro":[0,0,15,0],
-"page_fbx.html":[0,0,21,9],
-"page_fbx.html":[0,0,25,3],
-"page_fbx.html#fbx_antenna":[0,0,21,9,3],
-"page_fbx.html#fbx_antenna":[0,0,25,3,3],
-"page_fbx.html#fbx_atr":[0,0,21,9,5],
-"page_fbx.html#fbx_atr":[0,0,25,3,5],
-"page_fbx.html#fbx_leds":[0,0,21,9,3,0],
-"page_fbx.html#fbx_leds":[0,0,25,3,3,0],
-"page_fbx.html#fbx_overview":[0,0,21,9,0],
-"page_fbx.html#fbx_overview":[0,0,25,3,0],
-"page_fbx.html#fbx_sensors":[0,0,21,9,4],
-"page_fbx.html#fbx_sensors":[0,0,25,3,4],
-"page_fbx.html#fbx_too":[0,0,21,9,1],
-"page_fbx.html#fbx_too":[0,0,25,3,1],
-"page_fbx.html#fbx_too_dctrl":[0,0,21,9,2],
-"page_fbx.html#fbx_too_dctrl":[0,0,25,3,2],
+"page_fbx.html":[0,0,23,3],
+"page_fbx.html#fbx_antenna":[0,0,23,3,3],
+"page_fbx.html#fbx_atr":[0,0,23,3,5],
+"page_fbx.html#fbx_leds":[0,0,23,3,3,0],
+"page_fbx.html#fbx_overview":[0,0,23,3,0],
+"page_fbx.html#fbx_sensors":[0,0,23,3,4],
+"page_fbx.html#fbx_too":[0,0,23,3,1],
+"page_fbx.html#fbx_too_dctrl":[0,0,23,3,2],
 "page_general.html":[0,0,1],
 "page_general.html#general_misc":[0,0,1,4],
 "page_general.html#general_misc_dynamic":[0,0,1,4,0],
@@ -104,40 +95,40 @@ var NAVTREEINDEX18 =
 "page_general.html#general_tuning_rfsettling":[0,0,1,0,3],
 "page_general.html#general_tuning_rxchain":[0,0,1,0,0,0],
 "page_general.html#general_tuning_waitcode":[0,0,1,0,3,0],
-"page_gpio_api.html":[0,0,20,14],
-"page_gpio_api.html#autotoc_md10":[0,0,20,14,0,2,0],
-"page_gpio_api.html#autotoc_md9":[0,0,20,14,0,1,1],
-"page_gpio_api.html#e320_gpio_conn":[0,0,20,14,0,2],
-"page_gpio_api.html#egpio_internal_conn":[0,0,20,14,0,1,0],
-"page_gpio_api.html#egpio_internal_gpio":[0,0,20,14,0,1],
-"page_gpio_api.html#xgpio_fpanel":[0,0,20,14,0],
-"page_gpio_api.html#xgpio_fpanel_atr":[0,0,20,14,0,3],
-"page_gpio_api.html#xgpio_fpanel_conn":[0,0,20,14,0,0,0],
-"page_gpio_api.html#xgpio_fpanel_gpio":[0,0,20,14,0,0],
-"page_gpio_api.html#xgpio_fpanel_pins":[0,0,20,14,0,0,1],
-"page_gpio_api.html#xgpio_fpanel_xample":[0,0,20,14,0,4],
+"page_gpio_api.html":[0,0,19,14],
+"page_gpio_api.html#autotoc_md10":[0,0,19,14,0,2,0],
+"page_gpio_api.html#autotoc_md9":[0,0,19,14,0,1,1],
+"page_gpio_api.html#e320_gpio_conn":[0,0,19,14,0,2],
+"page_gpio_api.html#egpio_internal_conn":[0,0,19,14,0,1,0],
+"page_gpio_api.html#egpio_internal_gpio":[0,0,19,14,0,1],
+"page_gpio_api.html#xgpio_fpanel":[0,0,19,14,0],
+"page_gpio_api.html#xgpio_fpanel_atr":[0,0,19,14,0,3],
+"page_gpio_api.html#xgpio_fpanel_conn":[0,0,19,14,0,0,0],
+"page_gpio_api.html#xgpio_fpanel_gpio":[0,0,19,14,0,0],
+"page_gpio_api.html#xgpio_fpanel_pins":[0,0,19,14,0,0,1],
+"page_gpio_api.html#xgpio_fpanel_xample":[0,0,19,14,0,4],
 "page_gpsdo.html":[0,0,16,10],
-"page_gpsdo.html":[0,0,24,6],
+"page_gpsdo.html":[0,0,22,6],
 "page_gpsdo.html#gpsdo_install":[0,0,16,10,1],
-"page_gpsdo.html#gpsdo_install":[0,0,24,6,1],
+"page_gpsdo.html#gpsdo_install":[0,0,22,6,1],
 "page_gpsdo.html#gpsdo_specs":[0,0,16,10,0],
-"page_gpsdo.html#gpsdo_specs":[0,0,24,6,0],
+"page_gpsdo.html#gpsdo_specs":[0,0,22,6,0],
 "page_gpsdo.html#gpsdo_use":[0,0,16,10,2],
-"page_gpsdo.html#gpsdo_use":[0,0,24,6,2],
+"page_gpsdo.html#gpsdo_use":[0,0,22,6,2],
 "page_gpsdo.html#gspdo_install_post":[0,0,16,10,1,0],
-"page_gpsdo.html#gspdo_install_post":[0,0,24,6,1,0],
-"page_gpsdo_b2x0.html":[0,0,18,9],
-"page_gpsdo_b2x0.html#gpsdob_install":[0,0,18,9,1],
-"page_gpsdo_b2x0.html#gpsdob_power":[0,0,18,9,3],
-"page_gpsdo_b2x0.html#gpsdob_specs":[0,0,18,9,0],
-"page_gpsdo_b2x0.html#gpsdob_using":[0,0,18,9,2],
-"page_gpsdo_x3x0.html":[0,0,20,13],
-"page_gpsdo_x3x0.html#gpsdox_custom_cmds":[0,0,20,13,2,2],
-"page_gpsdo_x3x0.html#gpsdox_install":[0,0,20,13,1],
-"page_gpsdo_x3x0.html#gpsdox_sensors":[0,0,20,13,2,1],
-"page_gpsdo_x3x0.html#gpsdox_setting_gps_time":[0,0,20,13,2,0],
-"page_gpsdo_x3x0.html#gpsdox_specs":[0,0,20,13,0],
-"page_gpsdo_x3x0.html#gpsdox_using":[0,0,20,13,2],
+"page_gpsdo.html#gspdo_install_post":[0,0,22,6,1,0],
+"page_gpsdo_b2x0.html":[0,0,17,9],
+"page_gpsdo_b2x0.html#gpsdob_install":[0,0,17,9,1],
+"page_gpsdo_b2x0.html#gpsdob_power":[0,0,17,9,3],
+"page_gpsdo_b2x0.html#gpsdob_specs":[0,0,17,9,0],
+"page_gpsdo_b2x0.html#gpsdob_using":[0,0,17,9,2],
+"page_gpsdo_x3x0.html":[0,0,19,13],
+"page_gpsdo_x3x0.html#gpsdox_custom_cmds":[0,0,19,13,2,2],
+"page_gpsdo_x3x0.html#gpsdox_install":[0,0,19,13,1],
+"page_gpsdo_x3x0.html#gpsdox_sensors":[0,0,19,13,2,1],
+"page_gpsdo_x3x0.html#gpsdox_setting_gps_time":[0,0,19,13,2,0],
+"page_gpsdo_x3x0.html#gpsdox_specs":[0,0,19,13,0],
+"page_gpsdo_x3x0.html#gpsdox_using":[0,0,19,13,2],
 "page_identification.html":[0,0,2],
 "page_identification.html#id_identifying":[0,0,2,0],
 "page_identification.html#id_identifying_api":[0,0,2,0,2],
@@ -192,34 +183,34 @@ var NAVTREEINDEX18 =
 "page_multiple.html#multiple_intro":[0,0,4,0],
 "page_multiple.html#multiple_mimo":[0,0,4,3],
 "page_multiple.html#multiple_setup":[0,0,4,1],
-"page_ni_rio_kernel.html":[0,0,20,16],
-"page_ni_rio_kernel.html#linux_enabling":[0,0,20,16,0,3],
-"page_ni_rio_kernel.html#linux_installation":[0,0,20,16,0,2],
-"page_ni_rio_kernel.html#linux_overview":[0,0,20,16,0,0],
-"page_ni_rio_kernel.html#linux_requirements":[0,0,20,16,0,1],
-"page_ni_rio_kernel.html#linux_rio":[0,0,20,16,0],
-"page_ni_rio_kernel.html#linux_swapping":[0,0,20,16,0,4],
-"page_ni_rio_kernel.html#linux_uninstalling":[0,0,20,16,0,6],
-"page_ni_rio_kernel.html#linux_upgrades":[0,0,20,16,0,5],
-"page_ni_rio_kernel.html#win_enabling":[0,0,20,16,1,2],
-"page_ni_rio_kernel.html#win_install":[0,0,20,16,1,1],
-"page_ni_rio_kernel.html#win_requirements":[0,0,20,16,1,0],
-"page_ni_rio_kernel.html#win_swapping":[0,0,20,16,1,3],
-"page_ni_rio_kernel.html#win_uninstall":[0,0,20,16,1,4],
-"page_ni_rio_kernel.html#windows_rio":[0,0,20,16,1],
-"page_octoclock.html":[0,0,26],
-"page_octoclock.html#boot_process":[0,0,26,3,0],
-"page_octoclock.html#bootloader":[0,0,26,2,1],
-"page_octoclock.html#detecting_new_unit":[0,0,26,1],
-"page_octoclock.html#eeprom":[0,0,26,2,3],
-"page_octoclock.html#firmware":[0,0,26,2,2],
-"page_octoclock.html#front_panel_leds":[0,0,26,3,2],
-"page_octoclock.html#getting_latest":[0,0,26,2,0],
-"page_octoclock.html#octoclock_features":[0,0,26,0],
-"page_octoclock.html#selecting":[0,0,26,3,1],
-"page_octoclock.html#uhd":[0,0,26,3,3],
-"page_octoclock.html#upgrading_device":[0,0,26,2],
-"page_octoclock.html#usage":[0,0,26,3],
+"page_ni_rio_kernel.html":[0,0,19,16],
+"page_ni_rio_kernel.html#linux_enabling":[0,0,19,16,0,3],
+"page_ni_rio_kernel.html#linux_installation":[0,0,19,16,0,2],
+"page_ni_rio_kernel.html#linux_overview":[0,0,19,16,0,0],
+"page_ni_rio_kernel.html#linux_requirements":[0,0,19,16,0,1],
+"page_ni_rio_kernel.html#linux_rio":[0,0,19,16,0],
+"page_ni_rio_kernel.html#linux_swapping":[0,0,19,16,0,4],
+"page_ni_rio_kernel.html#linux_uninstalling":[0,0,19,16,0,6],
+"page_ni_rio_kernel.html#linux_upgrades":[0,0,19,16,0,5],
+"page_ni_rio_kernel.html#win_enabling":[0,0,19,16,1,2],
+"page_ni_rio_kernel.html#win_install":[0,0,19,16,1,1],
+"page_ni_rio_kernel.html#win_requirements":[0,0,19,16,1,0],
+"page_ni_rio_kernel.html#win_swapping":[0,0,19,16,1,3],
+"page_ni_rio_kernel.html#win_uninstall":[0,0,19,16,1,4],
+"page_ni_rio_kernel.html#windows_rio":[0,0,19,16,1],
+"page_octoclock.html":[0,0,24],
+"page_octoclock.html#boot_process":[0,0,24,3,0],
+"page_octoclock.html#bootloader":[0,0,24,2,1],
+"page_octoclock.html#detecting_new_unit":[0,0,24,1],
+"page_octoclock.html#eeprom":[0,0,24,2,3],
+"page_octoclock.html#firmware":[0,0,24,2,2],
+"page_octoclock.html#front_panel_leds":[0,0,24,3,2],
+"page_octoclock.html#getting_latest":[0,0,24,2,0],
+"page_octoclock.html#octoclock_features":[0,0,24,0],
+"page_octoclock.html#selecting":[0,0,24,3,1],
+"page_octoclock.html#uhd":[0,0,24,3,3],
+"page_octoclock.html#upgrading_device":[0,0,24,2],
+"page_octoclock.html#usage":[0,0,24,3],
 "page_power.html":[0,0,14],
 "page_power.html#power_amp_rate":[0,0,14,2],
 "page_power.html#power_cal_switch":[0,0,14,6,0],
@@ -249,5 +240,14 @@ var NAVTREEINDEX18 =
 "page_python.html":[0,1,2],
 "page_python.html#python_install":[0,1,2,0],
 "page_python.html#python_install_adv":[0,1,2,0,1],
-"page_python.html#python_install_windows":[0,1,2,0,0]
+"page_python.html#python_install_windows":[0,1,2,0,0],
+"page_python.html#python_usage":[0,1,2,1],
+"page_python.html#python_usage_gil":[0,1,2,3],
+"page_python.html#python_usage_oneoff":[0,1,2,2],
+"page_rdtesting.html":[0,1,9],
+"page_rdtesting.html#autotoc_md14":[0,1,9,1,1,0],
+"page_rdtesting.html#autotoc_md15":[0,1,9,1,1,1],
+"page_rdtesting.html#autotoc_md28":[0,1,9,4,2,0],
+"page_rdtesting.html#autotoc_md29":[0,1,9,4,2,0,0],
+"page_rdtesting.html#autotoc_md30":[0,1,9,4,2,0,1]
 };
