@@ -1,7 +1,7 @@
 var searchData=
 [
-  ['jtag_0',['JTAG',['../page_usrp_x4xx.html#x4xx_jtag_boot',1,'Booting X4x0 over JTAG'],['../md_usrp3_2vivado__env__utils.html#autotoc_md252',1,'Program device over JTAG']]],
-  ['jtag_20devices_1',['List connected JTAG devices',['../md_usrp3_2vivado__env__utils.html#autotoc_md251',1,'']]],
+  ['jtag_0',['Program device over JTAG',['../md_usrp3_2vivado__env__utils.html#autotoc_md251',1,'']]],
+  ['jtag_20devices_1',['List connected JTAG devices',['../md_usrp3_2vivado__env__utils.html#autotoc_md250',1,'']]],
   ['jtag_20programmer_2',['On-Board JTAG Programmer',['../page_usrp_x3x0.html#x3x0_jtag',1,'']]],
   ['jtag_20to_20load_20fpga_20images_3',['Use JTAG to load FPGA images',['../page_usrp_x3x0.html#x3x0_load_fpga_imgs_jtag',1,'']]],
   ['just_5freload_4',['just_reload',['../structuhd_1_1image__loader_1_1image__loader__args__t.html#ae8324082d336d1d787752f724e7bc676',1,'uhd::image_loader::image_loader_args_t']]]
