@@ -5,8 +5,5 @@ var searchData=
   ['has_5ftime_5fspec_2',['has_time_spec',['../structuhd_1_1rx__metadata__t.html#a7cd978c6290c12f3bb92072286109123',1,'uhd::rx_metadata_t::has_time_spec'],['../structuhd_1_1tx__metadata__t.html#af8f34976fc468381bfc662f57a398360',1,'uhd::tx_metadata_t::has_time_spec'],['../structuhd_1_1async__metadata__t.html#a333d1558d0bf0621f4476fcab2e8a269',1,'uhd::async_metadata_t::has_time_spec']]],
   ['has_5ftlr_3',['has_tlr',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#aae2d1fc554402f5eda38879578af0add',1,'uhd::transport::vrt::if_packet_info_t']]],
   ['has_5ftsf_4',['has_tsf',['../structuhd_1_1rfnoc_1_1tx__event__action__info.html#a7621de07341c51598b8a0954ec094ec3',1,'uhd::rfnoc::tx_event_action_info::has_tsf'],['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#a05620235be16ac3b9ad1eaf0864d6627',1,'uhd::transport::vrt::if_packet_info_t::has_tsf']]],
-  ['has_5ftsi_5',['has_tsi',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#a9dcd8f46d3f39627945dd9d429fec8a3',1,'uhd::transport::vrt::if_packet_info_t']]],
-  ['html_5fextra_5fpath_6',['html_extra_path',['../namespaceconf.html#a72a8d895fb309fffe9ad08b6f97217ca',1,'conf']]],
-  ['html_5ftheme_7',['html_theme',['../namespaceconf.html#a012ba9863b958ed7baa933116f2a05b6',1,'conf']]],
-  ['htmlhelp_5fbasename_8',['htmlhelp_basename',['../namespaceconf.html#ad9d7d7cfcf6e22cc48ad369cded0448a',1,'conf']]]
+  ['has_5ftsi_5',['has_tsi',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#a9dcd8f46d3f39627945dd9d429fec8a3',1,'uhd::transport::vrt::if_packet_info_t']]]
 ];
